$file=$args[0]
$token=$args[1]
$url=$args[2]

function Log-Message
{
    [CmdletBinding()]
    Param
    (
        [Parameter(Mandatory=$true, Position=0)]
        [string]$LogMessage
    )

    Write-Output ("[{0}] {1}" -f (Get-Date -Format "yyyy-MM-dd HH:mm:ss.fff K"), $LogMessage)
}

$agentstable = Import-Csv -Path $file -Delimiter ";"

$counter = 1

Log-Message "Starting adding Agents from csv file"

foreach ($agent in $agentstable)
{
	Log-Message "Processing new Agent from csv file, row #$counter"
	$Uri = "$url/api/settings/users/save"
	$Headers = @{"Authorization" = "Bearer $token"}
	$SipAccount = @{
		'login' = $agent.siplogin
		'password' = $agent.sippassword
		'displayName'= $agent.sipdisplayname
		'authName'=$agent.sipauthname
		'extensionNumber'=$agent.ext
	}	
	$groupsIn = $agent.groupsIn.Split(",")
	$groupsInInt = @()
	if ($agent.groupsIn[0] -ne $null)
	{
		foreach ($number in $groupsIn) {
			$groupsInInt += [int] $number
			}
	}
	$groupsMan = $agent.groupsMan.Split(",")
	$groupsManInt = @()
	if ($agent.groupsMan[0] -ne $null)
	{
		foreach ($number in $groupsMan) {
			$groupsManInt += [int] $number
			}
	}
	[bool]$usesSpBool = $false
	if ($agent.usesSP -eq "true")
	{
		$usesSpBool = $true
	}
	$Body = @{
		'usesSoftphone' = $usesSpBool
		'name' = $agent.name
		'surname' = $agent.surname
		'email' = $agent.email
		'password' = $agent.password
		'role' = $agent.role
		'groups' = $groupsInInt
		'managesGroups' = $groupsManInt
		'state'=''
		'config'='{% include "_Restrictions" %}' + "`n" + '{% include "_SipSettings" %}' + "`n" + '{% include "_Account1" %}' + "`n" + '{% include "_ACW" %}' + "`n" + '{% include "_Statuses" %}' + "`n" + '{% include "_Camera" %}' + "`n" + '{% include "_ScreenRecording" %}' + "`n" + '{% include "_HideIncomingNumbers" %}' + "`n" + '{% include "_Messaging" %}' + "`n" + '{% include "Default" %}'
		'sipAccount' = $SipAccount
	}
	$BodyJson = ConvertTo-Json $Body -Compress
	
	try
	{
		$Response = Invoke-WebRequest -URI $Uri -Headers $Headers -ContentType 'application/json' -Body $BodyJson -Method 'POST'
		$StatusCode = $Response.StatusCode
		$UserId = $Response.Content
	} catch {
		$StatusCode = $_.Exception.Response.StatusCode.value__
		$UserId = 0
	}
	
	if ($StatusCode -ne 200)
	{
		Log-Message "Error adding user #$counter from csv, got error $StatusCode from Team Dashboard."
	}
	else
	{
		Log-Message "Successfully added user #$counter from csv with ID $UserId"
	}
	$counter++
}

Log-Message "Finished adding Agents from csv file"